==> zio-aws-evidently_2.12-5.17.155.1-sources.jar: zio/aws/evidently/model/ProjectSummary.scala <==
package zio.aws.evidently.model
import zio.aws.evidently.model.primitives.{
  ProjectName,
  Timestamp,
  TagValue,
  ProjectArn,
  Description,
  TagKey
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import java.time.Instant
import scala.jdk.CollectionConverters._
final case class ProjectSummary(
    activeExperimentCount: Option[Long] = None,
    activeLaunchCount: Option[Long] = None,
    arn: ProjectArn,
    createdTime: Timestamp,
    description: Option[Description] = None,
    experimentCount: Option[Long] = None,
    featureCount: Option[Long] = None,
    lastUpdatedTime: Timestamp,
    launchCount: Option[Long] = None,
    name: ProjectName,
    status: zio.aws.evidently.model.ProjectStatus,
    tags: Option[Map[TagKey, TagValue]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.evidently.model.ProjectSummary = {
    import ProjectSummary.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.evidently.model.ProjectSummary
      .builder()
      .optionallyWith(
        activeExperimentCount.map(value => value: java.lang.Long)
      )(_.activeExperimentCount)
      .optionallyWith(activeLaunchCount.map(value => value: java.lang.Long))(
        _.activeLaunchCount
      )
      .arn(ProjectArn.unwrap(arn): java.lang.String)
      .createdTime(Timestamp.unwrap(createdTime): Instant)
      .optionallyWith(
        description.map(value => Description.unwrap(value): java.lang.String)
      )(_.description)
      .optionallyWith(experimentCount.map(value => value: java.lang.Long))(
        _.experimentCount
      )
      .optionallyWith(featureCount.map(value => value: java.lang.Long))(
        _.featureCount
      )
      .lastUpdatedTime(Timestamp.unwrap(lastUpdatedTime): Instant)
      .optionallyWith(launchCount.map(value => value: java.lang.Long))(
        _.launchCount
      )
      .name(ProjectName.unwrap(name): java.lang.String)
      .status(status.unwrap)
      .optionallyWith(
        tags.map(value =>
          value
            .map({ case (key, value) =>
              (TagKey.unwrap(key): java.lang.String) -> (TagValue
                .unwrap(value): java.lang.String)
            })
            .asJava
        )
      )(_.tags)
      .build()
  }
  def asReadOnly: zio.aws.evidently.model.ProjectSummary.ReadOnly =
    zio.aws.evidently.model.ProjectSummary.wrap(buildAwsValue())
}
object ProjectSummary {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.evidently.model.ProjectSummary
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.evidently.model.ProjectSummary =
      zio.aws.evidently.model.ProjectSummary(
        activeExperimentCount.map(value => value),
        activeLaunchCount.map(value => value),
        arn,
        createdTime,
        description.map(value => value),
        experimentCount.map(value => value),
        featureCount.map(value => value),
        lastUpdatedTime,
        launchCount.map(value => value),
        name,
        status,
        tags.map(value => value)
      )
    def activeExperimentCount: Option[Long]
    def activeLaunchCount: Option[Long]
    def arn: ProjectArn
    def createdTime: Timestamp
    def description: Option[Description]
    def experimentCount: Option[Long]
    def featureCount: Option[Long]
    def lastUpdatedTime: Timestamp
    def launchCount: Option[Long]
    def name: ProjectName
    def status: zio.aws.evidently.model.ProjectStatus
    def tags: Option[Map[TagKey, TagValue]]
    def getActiveExperimentCount: ZIO[Any, AwsError, Long] =
      AwsError.unwrapOptionField("activeExperimentCount", activeExperimentCount)
    def getActiveLaunchCount: ZIO[Any, AwsError, Long] =
      AwsError.unwrapOptionField("activeLaunchCount", activeLaunchCount)
    def getArn: ZIO[Any, Nothing, ProjectArn] = ZIO.succeed(arn)
    def getCreatedTime: ZIO[Any, Nothing, Timestamp] = ZIO.succeed(createdTime)
    def getDescription: ZIO[Any, AwsError, Description] =
      AwsError.unwrapOptionField("description", description)
    def getExperimentCount: ZIO[Any, AwsError, Long] =
      AwsError.unwrapOptionField("experimentCount", experimentCount)
    def getFeatureCount: ZIO[Any, AwsError, Long] =
      AwsError.unwrapOptionField("featureCount", featureCount)
    def getLastUpdatedTime: ZIO[Any, Nothing, Timestamp] =
      ZIO.succeed(lastUpdatedTime)
    def getLaunchCount: ZIO[Any, AwsError, Long] =
      AwsError.unwrapOptionField("launchCount", launchCount)
    def getName: ZIO[Any, Nothing, ProjectName] = ZIO.succeed(name)
    def getStatus: ZIO[Any, Nothing, zio.aws.evidently.model.ProjectStatus] =
      ZIO.succeed(status)
    def getTags: ZIO[Any, AwsError, Map[TagKey, TagValue]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.evidently.model.ProjectSummary
  ) extends zio.aws.evidently.model.ProjectSummary.ReadOnly {
    override val activeExperimentCount: Option[Long] =
      scala.Option(impl.activeExperimentCount()).map(value => value: Long)
    override val activeLaunchCount: Option[Long] =
      scala.Option(impl.activeLaunchCount()).map(value => value: Long)
    override val arn: ProjectArn =
      zio.aws.evidently.model.primitives.ProjectArn(impl.arn())
    override val createdTime: Timestamp =
      zio.aws.evidently.model.primitives.Timestamp(impl.createdTime())
    override val description: Option[Description] = scala
      .Option(impl.description())
      .map(value => zio.aws.evidently.model.primitives.Description(value))
    override val experimentCount: Option[Long] =
      scala.Option(impl.experimentCount()).map(value => value: Long)
    override val featureCount: Option[Long] =
      scala.Option(impl.featureCount()).map(value => value: Long)
    override val lastUpdatedTime: Timestamp =
      zio.aws.evidently.model.primitives.Timestamp(impl.lastUpdatedTime())
    override val launchCount: Option[Long] =
      scala.Option(impl.launchCount()).map(value => value: Long)
    override val name: ProjectName =
      zio.aws.evidently.model.primitives.ProjectName(impl.name())
    override val status: zio.aws.evidently.model.ProjectStatus =
      zio.aws.evidently.model.ProjectStatus.wrap(impl.status())
    override val tags: Option[Map[TagKey, TagValue]] = scala
      .Option(impl.tags())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.evidently.model.primitives
              .TagKey(key) -> zio.aws.evidently.model.primitives.TagValue(value)
          })
          .toMap
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.evidently.model.ProjectSummary
  ): zio.aws.evidently.model.ProjectSummary.ReadOnly = new Wrapper(impl)
}

==> zio-aws-evidently_2.12-5.17.197.2-sources.jar: zio/aws/evidently/model/ProjectSummary.scala <==
package zio.aws.evidently.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.evidently.model.primitives.{
  ProjectName,
  Timestamp,
  TagValue,
  ProjectArn,
  Description,
  TagKey
}
import scala.jdk.CollectionConverters._
final case class ProjectSummary(
    activeExperimentCount: Optional[Long] = Optional.Absent,
    activeLaunchCount: Optional[Long] = Optional.Absent,
    arn: ProjectArn,
    createdTime: Timestamp,
    description: Optional[Description] = Optional.Absent,
    experimentCount: Optional[Long] = Optional.Absent,
    featureCount: Optional[Long] = Optional.Absent,
    lastUpdatedTime: Timestamp,
    launchCount: Optional[Long] = Optional.Absent,
    name: ProjectName,
    status: zio.aws.evidently.model.ProjectStatus,
    tags: Optional[Map[TagKey, TagValue]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.evidently.model.ProjectSummary = {
    import ProjectSummary.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.evidently.model.ProjectSummary
      .builder()
      .optionallyWith(
        activeExperimentCount.map(value => value: java.lang.Long)
      )(_.activeExperimentCount)
      .optionallyWith(activeLaunchCount.map(value => value: java.lang.Long))(
        _.activeLaunchCount
      )
      .arn(ProjectArn.unwrap(arn): java.lang.String)
      .createdTime(Timestamp.unwrap(createdTime): Instant)
      .optionallyWith(
        description.map(value => Description.unwrap(value): java.lang.String)
      )(_.description)
      .optionallyWith(experimentCount.map(value => value: java.lang.Long))(
        _.experimentCount
      )
      .optionallyWith(featureCount.map(value => value: java.lang.Long))(
        _.featureCount
      )
      .lastUpdatedTime(Timestamp.unwrap(lastUpdatedTime): Instant)
      .optionallyWith(launchCount.map(value => value: java.lang.Long))(
        _.launchCount
      )
      .name(ProjectName.unwrap(name): java.lang.String)
      .status(status.unwrap)
      .optionallyWith(
        tags.map(value =>
          value
            .map({ case (key, value) =>
              (TagKey.unwrap(key): java.lang.String) -> (TagValue
                .unwrap(value): java.lang.String)
            })
            .asJava
        )
      )(_.tags)
      .build()
  }
  def asReadOnly: zio.aws.evidently.model.ProjectSummary.ReadOnly =
    zio.aws.evidently.model.ProjectSummary.wrap(buildAwsValue())
}
object ProjectSummary {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.evidently.model.ProjectSummary
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.evidently.model.ProjectSummary =
      zio.aws.evidently.model.ProjectSummary(
        activeExperimentCount.map(value => value),
        activeLaunchCount.map(value => value),
        arn,
        createdTime,
        description.map(value => value),
        experimentCount.map(value => value),
        featureCount.map(value => value),
        lastUpdatedTime,
        launchCount.map(value => value),
        name,
        status,
        tags.map(value => value)
      )
    def activeExperimentCount: Optional[Long]
    def activeLaunchCount: Optional[Long]
    def arn: ProjectArn
    def createdTime: Timestamp
    def description: Optional[Description]
    def experimentCount: Optional[Long]
    def featureCount: Optional[Long]
    def lastUpdatedTime: Timestamp
    def launchCount: Optional[Long]
    def name: ProjectName
    def status: zio.aws.evidently.model.ProjectStatus
    def tags: Optional[Map[TagKey, TagValue]]
    def getActiveExperimentCount: ZIO[Any, AwsError, Long] =
      AwsError.unwrapOptionField("activeExperimentCount", activeExperimentCount)
    def getActiveLaunchCount: ZIO[Any, AwsError, Long] =
      AwsError.unwrapOptionField("activeLaunchCount", activeLaunchCount)
    def getArn: ZIO[Any, Nothing, ProjectArn] = ZIO.succeed(arn)
    def getCreatedTime: ZIO[Any, Nothing, Timestamp] = ZIO.succeed(createdTime)
    def getDescription: ZIO[Any, AwsError, Description] =
      AwsError.unwrapOptionField("description", description)
    def getExperimentCount: ZIO[Any, AwsError, Long] =
      AwsError.unwrapOptionField("experimentCount", experimentCount)
    def getFeatureCount: ZIO[Any, AwsError, Long] =
      AwsError.unwrapOptionField("featureCount", featureCount)
    def getLastUpdatedTime: ZIO[Any, Nothing, Timestamp] =
      ZIO.succeed(lastUpdatedTime)
    def getLaunchCount: ZIO[Any, AwsError, Long] =
      AwsError.unwrapOptionField("launchCount", launchCount)
    def getName: ZIO[Any, Nothing, ProjectName] = ZIO.succeed(name)
    def getStatus: ZIO[Any, Nothing, zio.aws.evidently.model.ProjectStatus] =
      ZIO.succeed(status)
    def getTags: ZIO[Any, AwsError, Map[TagKey, TagValue]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.evidently.model.ProjectSummary
  ) extends zio.aws.evidently.model.ProjectSummary.ReadOnly {
    override val activeExperimentCount: Optional[Long] = zio.aws.core.internal
      .optionalFromNullable(impl.activeExperimentCount())
      .map(value => value: Long)
    override val activeLaunchCount: Optional[Long] = zio.aws.core.internal
      .optionalFromNullable(impl.activeLaunchCount())
      .map(value => value: Long)
    override val arn: ProjectArn =
      zio.aws.evidently.model.primitives.ProjectArn(impl.arn())
    override val createdTime: Timestamp =
      zio.aws.evidently.model.primitives.Timestamp(impl.createdTime())
    override val description: Optional[Description] = zio.aws.core.internal
      .optionalFromNullable(impl.description())
      .map(value => zio.aws.evidently.model.primitives.Description(value))
    override val experimentCount: Optional[Long] = zio.aws.core.internal
      .optionalFromNullable(impl.experimentCount())
      .map(value => value: Long)
    override val featureCount: Optional[Long] = zio.aws.core.internal
      .optionalFromNullable(impl.featureCount())
      .map(value => value: Long)
    override val lastUpdatedTime: Timestamp =
      zio.aws.evidently.model.primitives.Timestamp(impl.lastUpdatedTime())
    override val launchCount: Optional[Long] = zio.aws.core.internal
      .optionalFromNullable(impl.launchCount())
      .map(value => value: Long)
    override val name: ProjectName =
      zio.aws.evidently.model.primitives.ProjectName(impl.name())
    override val status: zio.aws.evidently.model.ProjectStatus =
      zio.aws.evidently.model.ProjectStatus.wrap(impl.status())
    override val tags: Optional[Map[TagKey, TagValue]] = zio.aws.core.internal
      .optionalFromNullable(impl.tags())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.evidently.model.primitives
              .TagKey(key) -> zio.aws.evidently.model.primitives.TagValue(value)
          })
          .toMap
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.evidently.model.ProjectSummary
  ): zio.aws.evidently.model.ProjectSummary.ReadOnly = new Wrapper(impl)
}
